%global pypi_name ironic-python-agent

Summary:        A python agent for provisioning and deprovisioning bare metal servers
Name:           openstack-%{pypi_name}
Version:        9.1.0
Release:        2%{?dist}
License:        ASL 2.0
URL:            https://github.com/openstack/ironic-python-agent
Source0:        %pypi_source
Source1:        openstack-%{pypi_name}.service
Source2:        %{pypi_name}-dist.conf

Patch0001:      0001-Fix-create-configuration-unit-tests.patch

BuildArch:      noarch

BuildRequires:  python3-setuptools python3-devel
BuildRequires:  python3-pbr python3-eventlet python3-netifaces
BuildRequires:  python3-oslo-config python3-oslo-concurrency python3-oslo-log
BuildRequires:  python3-oslo-serialization python3-oslo-service python3-oslo-utils
BuildRequires:  python3-pint python3-psutil python3-pyudev python3-requests
BuildRequires:  python3-rtslib python3-stevedore python3-tenacity
BuildRequires:  python3-ironic-lib python3-werkzeug python3-cryptography
BuildRequires:  python3-stestr python3-oslotest python-importlib-metadata python-tooz
BuildRequires:  systemd
Requires: python3-%{pypi_name} = %{version}-%{release}

%{?systemd_requires}

%description
An agent for controlling and deploying Ironic controlled bare metal nodes.

The ironic-python-agent works with the agent driver in Ironic to provision the
node. Starting with ironic-python-agent running on a ramdisk on the
unprovisioned node, Ironic makes API calls to ironic-python-agent to provision
the machine. This allows for greater control and flexibility of the entire
deployment process.

The ironic-python-agent may also be used with the original Ironic pxe drivers
as of the Kilo OpenStack release.

%package -n python3-%{pypi_name}
Summary:        Python library for the ironic python agent.
Requires:       python3-pbr python3-eventlet python3-netifaces
Requires:       python3-oslo-config python3-oslo-concurrency python3-oslo-log
Requires:       python3-oslo-serialization python3-oslo-service python3-oslo-utils
Requires:       python3-pint python3-psutil python3-pyudev python3-requests
Requires:       python3-rtslib python3-stevedore python3-tenacity
Requires:       python3-ironic-lib python3-werkzeug python3-cryptography
Requires:       network-scripts

%description -n python3-%{pypi_name}
Python library for ironic python agent.

%prep
%autosetup -n %{pypi_name}-%{version} -p1

# The require of python3-rtslib-fb in requirements file is confilcts with
# python3-rtslib. Remove the requirements file to replace the require of
# python3-rtslib-fb with python3-rtslib.
rm -rf *requirements.txt

%build
%{py3_build}

%install
%{py3_install}

mkdir -p %{buildroot}%{_unitdir}
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}
install -p -D -m 640 %{SOURCE2} %{buildroot}/%{_sysconfdir}/%{pypi_name}/%{pypi_name}-dist.conf

%check
export PYTHON=%{__python3}
stestr --test-path ironic_python_agent/tests/unit run

%files
%license LICENSE
%doc README.rst
%config(noreplace) %attr(-,root,root) %{_sysconfdir}/%{pypi_name}
%{_bindir}/%{pypi_name}
%{_bindir}/ironic-collect-introspection-data
%{_unitdir}/openstack-%{pypi_name}.service

%files -n python3-%{pypi_name}
%license LICENSE
%{python3_sitelib}/*

%post
%systemd_post openstack-%{pypi_name}.service

%preun
%systemd_preun openstack-%{pypi_name}.service

%postun
%systemd_postun_with_restart openstack-%{pypi_name}.service

%changelog
* Wed Oct 11 2023 Shuo Wang <abushwang@tencent.com> - 9.1.0-2
- backport patch to fix create configuration unit tests

* Sat Oct 07 2023 Miaojun Dong <zoedong@tencent.com> - 9.1.0-1
- Bump version to 9.1.0

* Wed Sep 20 2023 kianli <kianli@tencent.com> - 7.0.2-6
- Backport use Werkzeug modern version patch

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.0.2-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.0.2-4
- Rebuilt for OpenCloudOS Stream 23.09

* Sat May 06 2023 kianli <kianli@tencent.com> - 7.0.2-3
- replace the require of python3-rtslib-fb with python3-rtslib

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.0.2-2
- Rebuilt for OpenCloudOS Stream 23.05

* Mon Apr 17 2023 kianli <kianli@tencent.com> - 7.0.2-1
- initial build
